#!/bin/sh
VERSION=1.2
FILES=http://files.directadmin.com

CHECK=0
ALL_HAVE_IMAP=1
if [ $# -ge 1 ]; then
	case "$1" in
		--check) CHECK=1;
				;;
		*)	echo "Usage:"
			echo "  $0            - Install imap to all php versions"
			echo "  $0 --check    - Exit 1 if anything flagged needs to be compiled. 0 if IMAP fully installed."
			exit 1;
			;;
	esac
fi

WEB=ap2
CONFIGURE=configure.php5
VER=2007f

CB=/usr/local/directadmin/custombuild
O=/usr/local/directadmin/custombuild/options.conf
CB_VER=1
V=`grep '^custombuild=' $O | cut -d= -f2 | cut -d. -f1`
if [ "$V" = "2" ]; then
	CB_VER=2;

	PHP_CONFIGURE=`${CB}/build used_configs | grep 'PHP (default) configuration file' | cut -d: -f2 | cut -d\  -f2`
	PHP_VER=`grep php1_release ${O} | head -n1 | cut -d= -f2`
	PHP2_CONFIGURE=`${CB}/build used_configs | grep 'PHP (additional) configuration file' | cut -d: -f2 | cut -d\  -f2`
	PHP3_CONFIGURE=`${CB}/build used_configs | grep 'PHP (additional, 3rd) configuration file' | cut -d: -f2 | cut -d\  -f2`
	PHP4_CONFIGURE=`${CB}/build used_configs | grep 'PHP (additional, 4th) configuration file' | cut -d: -f2 | cut -d\  -f2`

	#make sure its sane:
	if ! echo ${PHP_CONFIGURE} | grep -m1 -q 'configure.php'; then
		echo "Cannot extract php configure from path: ${PHP_CONFIGURE}";
		exit 1;
	fi

	#works for both configure and custom folders, as its the same count.
	CONFIGURE=`echo ${PHP_CONFIGURE} | cut -d/ -f8`
	WEB=`echo ${PHP_CONFIGURE} | cut -d/ -f7`

	echo "CustomBuild 2.0";
	echo "WEB=${WEB}";
	echo "CONFIGURE=${CONFIGURE}";

	if echo ${PHP2_CONFIGURE} | grep -m1 -q 'configure.php'; then
		CONFIGURE2=`echo ${PHP2_CONFIGURE} | cut -d/ -f8`
		WEB2=`echo ${PHP2_CONFIGURE} | cut -d/ -f7`
		echo "WEB2=${WEB2}";
		echo "CONFIGURE2=${CONFIGURE2}";
		PHP2_VER=`grep php2_release ${O} | head -n1 | cut -d= -f2`
	fi
	if echo ${PHP3_CONFIGURE} | grep -m1 -q 'configure.php'; then
		CONFIGURE3=`echo ${PHP3_CONFIGURE} | cut -d/ -f8`
		WEB3=`echo ${PHP3_CONFIGURE} | cut -d/ -f7`
		echo "WEB3=${WEB3}";
		echo "CONFIGURE3=${CONFIGURE3}";
		PHP3_VER=`grep php3_release ${O} | head -n1 | cut -d= -f2`
	fi
	if echo ${PHP4_CONFIGURE} | grep -m1 -q 'configure.php'; then
		CONFIGURE4=`echo ${PHP4_CONFIGURE} | cut -d/ -f8`
		WEB4=`echo ${PHP4_CONFIGURE} | cut -d/ -f7`
		echo "WEB4=${WEB4}";
		echo "CONFIGURE4=${CONFIGURE4}";
		PHP4_VER=`grep php4_release ${O} | head -n1 | cut -d= -f2`
	fi
fi

if [ "${CHECK}" -ne 1 ]; then
	if [ -s /etc/debian_version ]; then
		apt-get -y install libpam0g-dev
	else
		yum -y install pam-devel
	fi
fi

cd /usr/local

if [ "${CHECK}" -eq 1 ]; then
	if [ ! -s /usr/local/imap-${VER}/lib/libc-client.a ]; then
		echo "Cannot find libc-client.a. Flagged."
		ALL_HAVE_IMAP=0
	fi
fi

if [ "${CHECK}" -ne 1 ]; then
	wget -O imap-${VER}.tar.gz ${FILES}/services/all/imap/imap-${VER}.tar.gz
	if [ ! -s imap-${VER}.tar.gz ]; then
		echo "Cannot find imap-${VER}.tar.gz for extraction";
		exit 1;
	fi
	tar xvzf imap-${VER}.tar.gz
	cd imap-${VER}

	UW_PATCH=1006_openssl1.1_autoverify.patch
	wget -O ${UW_PATCH} ${FILES}/services/custombuild/patches/${UW_PATCH}
	if [ -s ${UW_PATCH} ]; then
		patch -p1 < ${UW_PATCH}
	else
		echo "Cannot get uw-imap openssl patch: ${UW_PATCH}"
		echo '    https://bugs.debian.org/828589'
		echo '    https://bugzilla.redhat.com/attachment.cgi?id=1388349&action=diff#a/1006_openssl1.1_autoverify.patch_sec1'
	fi

	make lr5 EXTRACFLAGS=-fPIC
	mkdir lib
	mkdir include
	cp c-client/*.c lib/
	cp c-client/*.h include/
	cp c-client/c-client.a lib/libc-client.a
fi

find_php_without_imap()
{
	PV=$1
	P_BIN=$2

	if [ "$PV" = "no" ] || [ "$PV" = "" ]; then
		return;
	fi

	if [ "$P_BIN" = "" ]; then
		P_BIN=/usr/local/php${PV//./}/bin/php${PV//./}
	fi

	if [ ! -x ${P_BIN} ]; then
		echo "Cannot find ${P_BIN} to verify IMAP. Flagged."
		ALL_HAVE_IMAP=0
		return;
	fi

	C=`${P_BIN} -i | grep -c 'IMAP c-Client'`
	if [ "$C" -eq 0 ]; then
		echo "${P_BIN} does not yet support IMAP.  Flagged."
		ALL_HAVE_IMAP=0
	fi
}

find_php_without_imap ${PHP_VER} /usr/local/bin/php
find_php_without_imap ${PHP2_VER} ''
find_php_without_imap ${PHP3_VER} ''
find_php_without_imap ${PHP4_VER} ''


if [ "${CHECK}" -eq 1 ]; then
	if [ "${ALL_HAVE_IMAP}" -eq 1 ]; then
		exit 0
	else
		exit 1;
	fi
fi


cd /usr/local/directadmin/custombuild
if [ ! -s custom/${WEB}/${CONFIGURE} ]; then
	mkdir -p custom/${WEB}
	cp configure/${WEB}/${CONFIGURE} custom/${WEB}/
fi

if ! grep -m1 -q with-imap custom/${WEB}/${CONFIGURE}; then
	perl -pi -e 's#--with-openssl \\#--with-openssl --with-imap=/usr/local/imap-2007f --with-imap-ssl \\#' custom/${WEB}/${CONFIGURE}
	perl -pi -e 's#"--with-openssl" \\#"--with-openssl" "--with-imap=/usr/local/imap-2007f" "--with-imap-ssl" \\#' custom/${WEB}/${CONFIGURE}
fi


set_configure()
{
	PHPX_CONFIGURE=$1
	WEBX=$2
	CONFIGUREX=$3

	if echo ${PHPX_CONFIGURE} | grep -m1 -q 'configure.php'; then
		if [ ! -s custom/${WEBX}/${CONFIGUREX} ]; then
			mkdir -p custom/${WEBX}
			cp configure/${WEBX}/${CONFIGUREX} custom/${WEBX}/
		fi
		if ! grep -m1 -q with-imap custom/${WEBX}/${CONFIGUREX}; then
			perl -pi -e 's#--with-openssl \\#--with-openssl --with-imap=/usr/local/imap-2007f --with-imap-ssl \\#' custom/${WEBX}/${CONFIGUREX}
			perl -pi -e 's#"--with-openssl" \\#"--with-openssl" "--with-imap=/usr/local/imap-2007f" "--with-imap-ssl" \\#' custom/${WEBX}/${CONFIGUREX}
		fi
	fi
}

set_configure "${PHP2_CONFIGURE}" "${WEB2}" "${CONFIGURE2}"
set_configure "${PHP3_CONFIGURE}" "${WEB3}" "${CONFIGURE3}"
set_configure "${PHP4_CONFIGURE}" "${WEB4}" "${CONFIGURE4}"


./build php n
